{smcl}
help for {hi:pearsonx2}
{hline}

{title:Pearson's X2 goodness-of-fit test for discrete regression models}

{p 8 16 2}
{cmd:pearsonx2}
[{cmd:,}
  {cmdab:e:ps(}{it:#}{cmd:)}
  {cmdab:t:able}
]

{p 4 4 2}{cmd:pearsonx2} is for use after {help logit}, {help logistic},
{help probit}, {help cloglog}, {help mlogit}, and {help clogit}.  In
the case of {cmd:clogit}, there should be exactly one positive outcome
per group.

{p 4 4 2}{cmd:pearsonx2} supports {cmd:fweight}s, but not {cmd:iweight}s
and {cmd:pweight}s.  It does not allow clustered observations.


{title:Description}

{p 4 4 2}Pearson's goodness-of-fit statistics is defined as
{hi:X2 = sum (obs-exp)^2/(exp(1-exp))}, with summation over all possible
outcomes for all individual observations.  In contrast to Pearson's test
for logistic regression as computed by {help lfit}, {cmd:pearsonx2} does
not aggregate over covariance patterns.

{p 4 4 2}While one often assumes that X2 is approximately chi-square
distributed, this is generally not true.  Windmeijer (1990, 1994)
derived normalizing constants m and s for each of the supported models.
(These "constants" are in fact fairly complicated expressions in the
response probabilities and covariates.)  Thus for some m and s,
{bind:H = (X2-m)/s} is approximately chi-square distributed with 1
degree of freedom if the model is well-specified.  Therefore, a value
of H larger than say 4 indicates misspecification.

{p 4 4 2}As typically the case with goodness-of-fit tests with unspecified
alternatives, the power against any specific form of misspecification
tends to be low.  Moreover, rejection by an omnibus tests gives no cue
about the nature of the misspecification.  Tests designed for specific
misspecifications generally have superior power and provide constructive
suggestions how to continue research.


{title:Options}

{p 4 4 2}{cmd:eps(}{it:#}{cmd:)}
specifies that only observations for which  the estimated probability
for all possible outcomes are greater than {it:#} are used in computing
the test.  {it:#} defaults to 1E-2.

{p 4 4 2}{cmd:table}
specifies that Windmeijer's test is conducted for various eps
(.1,.01,.001,etc) in order to assess the sensitivity of the test to
very small probabilities of some outcomes.


{title:Examples}

    {cmd:. logit employed edu exp male kids}
    {cmd:. pearsonx2}

    {cmd:. probit employed edu exp male kids}
    {cmd:. pearsonx2}

    {cmd:. mlogit rep78 price foreign}
    {cmd:. pearsonx2}

    {cmd:. clogit transp money time, group(respnr)}
    {cmd:. pearsonx2, table}


{title:References}

{phang}
Hosmer Jr, D.W. Lemeshow, S., Sturdivant, R.X. 2013.
   Applied logistic regression. 3nd edition. Wiley: New York.

{phang}
McCullagh, P. 1986.
   The conditional distribution of goodness-of-fit statistics for discrete
   data. Journal of the American Statistical Association 81: 104-107.

{phang}
Windmeijer, F.A.G. 1990.
   The asymptotic distribution of the sum of weighted squared residuals
   in binary choice models. Statistica Neerlandica 44, 2: 69-78.

{phang}
Windmeijer, F.A.G. 1994.
   A goodness-of-fit test in the multinomial logit model based on weighted
   squared residuals. Statistica Neerlandica 48, 3: 271-283.


{title:Author}

    Jeroen Weesie, Department of Sociology, Utrecht University
    email: j PERIOD weesie AT uu PERIOD nl 

{pstd}
This command requires Stata 13. An earlier version appeared in 
the Stata Technical Bulletin in 1999.


{title:Saved Results}

{pstd}
{cmd:pearsonx2} saves in {cmd:r()}:

{p 8 24}{cmd:r(N)}{space     12}number of observations{p_end}
{p 8 24}{cmd:r(N_drop)}{space 7}number of observations excluded{p_end}
{p 8 24}{cmd:r(X2)}{space    11}Pearson's ungrouped X2-statistic{p_end}
{p 8 24}{cmd:r(varX2)}{space  8}asymptotic variance of X2{p_end}
{p 8 24}{cmd:r(meanX2)}{space 7}asymptotic mean of X2{p_end}
{p 8 24}{cmd:r(chi2)}{space   9}Windmeijer's H, a normalization of X2,
that is approximately chi-square distributed with 1 df.


